==> ejc-task-api-3.0.0-20210123.085528-9-sources.jar: com/ejianc/business/center/vo/EarlyWarnTransVO.java <==
package com.ejianc.business.center.vo;

import java.io.Serializable;

/**
 * 预警中心
 * 
 * @author generator
 * 
 */
public class EarlyWarnTransVO  implements Serializable {
    private static final long serialVersionUID = 1L;

    private String sourceId; // 预警对象ID 目前可以传projectId 不传也行，暂时没用
    private Long tenantId;  // 租户id 必填 各个租户的租户id
    private Long orgId; // 此次预警的所属组织id，根据需求字段填写   必填
    private String earlywarnName; // 预警名称  必填 此次预警的预警名称，在调度参数中
    private String billName; // 预警单据名称   必填 根据需求生成的 预警单据名称
    private String earlywarnContent; // 预警内容   必填  根据需求拼接
    private Long warnSetId; // 对应预警设置id   必填 此次预警的预警设置的主键，在调度参数中，也是调度参数的主键
    private String pcUrl; // 穿透链接 pc端  根据需求填写完整pc端url，以https开头
    private String moUrl; // 穿透链接 移动端 根据需求填写完整移动端url，以https开头
    private String warnLevel; // 风险等级 此次预警的预警设置的风险等级，在调度参数中
    private String orgName; // 此次预警的所属组织名称，根据需求字段填写     必填

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getEarlywarnName() {
        return earlywarnName;
    }

    public void setEarlywarnName(String earlywarnName) {
        this.earlywarnName = earlywarnName;
    }

    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }

    public String getEarlywarnContent() {
        return earlywarnContent;
    }

    public void setEarlywarnContent(String earlywarnContent) {
        this.earlywarnContent = earlywarnContent;
    }

    public Long getWarnSetId() {
        return warnSetId;
    }

    public void setWarnSetId(Long warnSetId) {
        this.warnSetId = warnSetId;
    }

    public String getPcUrl() {
        return pcUrl;
    }

    public void setPcUrl(String pcUrl) {
        this.pcUrl = pcUrl;
    }

    public String getMoUrl() {
        return moUrl;
    }

    public void setMoUrl(String moUrl) {
        this.moUrl = moUrl;
    }

    public String getWarnLevel() {
        return warnLevel;
    }

    public void setWarnLevel(String warnLevel) {
        this.warnLevel = warnLevel;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}

==> ejc-task-api-3.0.0-20210309.124755-45-sources.jar: com/ejianc/business/center/vo/EarlyWarnTransVO.java <==
package com.ejianc.business.center.vo;

import java.io.Serializable;

/**
 * 预警中心
 * 
 * @author generator
 * 
 */
public class EarlyWarnTransVO  implements Serializable {
    private static final long serialVersionUID = 1L;

    private String sourceId; // 预警对象ID 目前可以传projectId 不传也行，暂时没用
    private Long tenantId;  // 租户id 必填 各个租户的租户id
    private Long orgId; // 此次预警的所属组织id，根据需求字段填写   必填
    private String earlywarnName; // 预警名称  必填 此次预警的预警名称，在调度参数中
    private String billName; // 预警单据名称   必填 根据需求生成的 预警单据名称
    private String earlywarnContent; // 预警内容   必填  根据需求拼接
    private Long warnSetId; // 对应预警设置id   必填 此次预警的预警设置的主键，在调度参数中，也是调度参数的主键
    private String pcUrl; // 穿透链接 pc端  根据需求填写pc端相关应用的url，以/开头，例如：/ejc-xx-frontend/#/xxx/xxx/xxx
    private String pcTitle; // pc端 穿透页签名称
    private String moUrl; // 穿透链接 移动端 根据需求填写完整移动端url，以https开头
    private String warnLevel; // 风险等级 此次预警的预警设置的风险等级，在调度参数中
    private String orgName; // 此次预警的所属组织名称，根据需求字段填写     必填

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getEarlywarnName() {
        return earlywarnName;
    }

    public void setEarlywarnName(String earlywarnName) {
        this.earlywarnName = earlywarnName;
    }

    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }

    public String getEarlywarnContent() {
        return earlywarnContent;
    }

    public void setEarlywarnContent(String earlywarnContent) {
        this.earlywarnContent = earlywarnContent;
    }

    public Long getWarnSetId() {
        return warnSetId;
    }

    public void setWarnSetId(Long warnSetId) {
        this.warnSetId = warnSetId;
    }

    public String getPcUrl() {
        return pcUrl;
    }

    public void setPcUrl(String pcUrl) {
        this.pcUrl = pcUrl;
    }

    public String getPcTitle() {
        return pcTitle;
    }

    public void setPcTitle(String pcTitle) {
        this.pcTitle = pcTitle;
    }

    public String getMoUrl() {
        return moUrl;
    }

    public void setMoUrl(String moUrl) {
        this.moUrl = moUrl;
    }

    public String getWarnLevel() {
        return warnLevel;
    }

    public void setWarnLevel(String warnLevel) {
        this.warnLevel = warnLevel;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}
